@@ -68,6 +68,7 @@ struct MyTexture3
 	int m_width;
 	int m_height;
 	bool m_isCached;
+	int m_innerTexUid;
 };
 
 struct EGLRendererObjectArray
@@ -78,12 +79,14 @@ struct EGLRendererObjectArray
 	int m_linkIndex;
 	btTransform m_worldTransform;
 	btVector3 m_localScaling;
-
+	b3AlignedObjectArray<GLInstanceVertex> m_vertices;
+	
 	EGLRendererObjectArray()
 	{
 		m_worldTransform.setIdentity();
 		m_localScaling.setValue(1, 1, 1);
 	}
+
 };
 
 //#define START_WIDTH 2560
@@ -173,7 +176,9 @@ struct EGLRendererVisualShapeConverterInternalData
 	float m_mouseXpos;
 	float m_mouseYpos;
 	bool m_mouseInitialized;
-	int m_graphicsUniqueIdGenerator;
+	
+	btAlignedObjectArray<unsigned char> m_checkeredTexels;
+
 
 	EGLRendererVisualShapeConverterInternalData()
 		: m_upAxis(2),
@@ -201,8 +206,8 @@ struct EGLRendererVisualShapeConverterInternalData
 		m_mouseMoveMultiplier(0.4f),
 		m_mouseXpos(0.f),
 		m_mouseYpos(0.f),
-		m_mouseInitialized(false),
-		m_graphicsUniqueIdGenerator(15)
+		m_mouseInitialized(false)
+		
 	{
 		m_depthBuffer.resize(m_swWidth * m_swHeight);
 		m_shadowBuffer.resize(m_swWidth * m_swHeight);
@@ -665,6 +670,41 @@ static void convertURDFToVisualShape2(const UrdfShape* visual, const char* urdfP
 			convexColShape->setMargin(0.001);
 			break;
 		}
+		case URDF_GEOM_HEIGHTFIELD:
+		{
+			glmesh = new GLInstanceGraphicsShape;
+			glmesh->m_scaling[0] = 1;
+			glmesh->m_scaling[1] = 1;
+			glmesh->m_scaling[2] = 1;
+			glmesh->m_scaling[3] = 1;
+			//		int index = 0;
+			glmesh->m_indices = new b3AlignedObjectArray<int>();
+			glmesh->m_vertices = new b3AlignedObjectArray<GLInstanceVertex>();
+			glmesh->m_indices->reserve(visual->m_geometry.m_indices.size());
+			for (int i = 0; i < visual->m_geometry.m_indices.size(); i++)
+			{
+				glmesh->m_indices->push_back(visual->m_geometry.m_indices[i]);
+			}
+			glmesh->m_vertices->reserve(visual->m_geometry.m_vertices.size());
+			for (int v = 0; v < visual->m_geometry.m_vertices.size(); v++)
+			{
+				GLInstanceVertex vtx;
+				vtx.xyzw[0] = visual->m_geometry.m_vertices[v].x();
+				vtx.xyzw[1] = visual->m_geometry.m_vertices[v].y();
+				vtx.xyzw[2] = visual->m_geometry.m_vertices[v].z();
+				vtx.xyzw[3] = 1;
+				vtx.uv[0] = visual->m_geometry.m_uvs[v].x();
+				vtx.uv[1] = visual->m_geometry.m_uvs[v].y();
+				vtx.normal[0] = visual->m_geometry.m_normals[v].x();
+				vtx.normal[1] = visual->m_geometry.m_normals[v].y();
+				vtx.normal[2] = visual->m_geometry.m_normals[v].z();
+				glmesh->m_vertices->push_back(vtx);
+			}
+
+			glmesh->m_numIndices = glmesh->m_indices->size();
+			glmesh->m_numvertices = glmesh->m_vertices->size();
+			break;
+		}
 		case URDF_GEOM_MESH:
 		{
 			strncpy(visualShapeOut.m_meshAssetFileName, visual->m_geometry.m_meshFileName.c_str(), VISUAL_SHAPE_MAX_PATH_LEN);
@@ -905,27 +945,130 @@ static void convertURDFToVisualShape2(const UrdfShape* visual, const char* urdfP
 }
 
 static btVector4 sColors[4] =
-	{
+{
 		btVector4(60. / 256., 186. / 256., 84. / 256., 1),
 		btVector4(244. / 256., 194. / 256., 13. / 256., 1),
 		btVector4(219. / 256., 50. / 256., 54. / 256., 1),
 		btVector4(72. / 256., 133. / 256., 237. / 256., 1),
-
-		//btVector4(1,1,0,1),
 };
 
+int EGLRendererVisualShapeConverter::registerShapeAndInstance(const b3VisualShapeData& visualShape, const float* vertices, int numvertices, const int* indices, int numIndices, int primitiveType, int textureId, int orgGraphicsUniqueId, int bodyUniqueId, int linkIndex)
+{
+	int uniqueId = orgGraphicsUniqueId;
+	float rgbaColor[4] = { (float)visualShape.m_rgbaColor[0],(float)visualShape.m_rgbaColor[1], (float)visualShape.m_rgbaColor[2],(float)visualShape.m_rgbaColor[3] };
+
+	EGLRendererObjectArray** visualsPtr = m_data->m_swRenderInstances[uniqueId];
+	if (visualsPtr == 0)
+	{
+		m_data->m_swRenderInstances.insert(uniqueId, new EGLRendererObjectArray);
+	}
+	visualsPtr = m_data->m_swRenderInstances[uniqueId];
+	if (visualsPtr)
+	{
+		EGLRendererObjectArray* visuals = *visualsPtr;
+
+		//////////////
+
+		B3_PROFILE("m_instancingRenderer register");
+
+		// register mesh to m_instancingRenderer too.
+
+		int innerTexId = -1;
+		if (textureId >= 0 && textureId < m_data->m_textures.size())
+		{
+			innerTexId = m_data->m_textures[textureId].m_innerTexUid;
+		}
+		
+		int shapeIndex = m_data->m_instancingRenderer->registerShape(&vertices[0],
+			numvertices, &indices[0], numIndices, B3_GL_TRIANGLES, innerTexId);
+
+		double scaling[3] = { visualShape.m_dimensions[0], visualShape.m_dimensions[1],visualShape.m_dimensions[2] };
+		double position[4] = { visualShape.m_localVisualFrame[0],visualShape.m_localVisualFrame[1],visualShape.m_localVisualFrame[2],1 };
+		double orn[4] = { visualShape.m_localVisualFrame[3],visualShape.m_localVisualFrame[4],visualShape.m_localVisualFrame[5],visualShape.m_localVisualFrame[6]};
+		
+		int graphicsIndex = m_data->m_instancingRenderer->registerGraphicsInstance(
+			shapeIndex,
+			position,
+			orn,
+			visualShape.m_rgbaColor,
+			scaling);
+
+		int segmentationMask = bodyUniqueId + ((linkIndex + 1) << 24);
+		{
+			if (graphicsIndex >= 0)
+			{
+				//visuals->m_graphicsInstanceIds.push_back(graphicsIndex);
+
+				if (m_data->m_graphicsIndexToSegmentationMask.size() < (graphicsIndex + 1))
+				{
+					m_data->m_graphicsIndexToSegmentationMask.resize(graphicsIndex + 1);
+				}
+				m_data->m_graphicsIndexToSegmentationMask[graphicsIndex] = segmentationMask;
+			}
+		}
+
+		m_data->m_instancingRenderer->writeTransforms();
+		GLInstanceVertex* orgVertices = (GLInstanceVertex*)vertices;
+		visuals->m_graphicsInstanceIds.push_back(graphicsIndex);
+		visuals->m_vertices.resize(numvertices);
+		for (int v = 0; v < numvertices; v++)
+		{
+			visuals->m_vertices[v] = orgVertices[v];
+		}
+	}
+
+	m_data->m_visualShapes.push_back(visualShape);
+	return uniqueId;
+}
+
+
+
+void EGLRendererVisualShapeConverter::updateShape(int shapeUniqueId, const btVector3* vertices, int numVertices, const btVector3* normals, int numNormals)
+{
+	EGLRendererObjectArray** visualsPtr = m_data->m_swRenderInstances[shapeUniqueId];
+	if (visualsPtr)
+	{
+		EGLRendererObjectArray* visuals = *visualsPtr;
+		for (int v = 0; v < visuals->m_graphicsInstanceIds.size(); v++)
+		{
+			int graphicsIndex = visuals->m_graphicsInstanceIds[v];
+			if (graphicsIndex >= 0)
+			{
+				btAssert(visuals->m_vertices.size() == numVertices);
+				if (visuals->m_vertices.size() == numVertices)
+				{
+					for (int i = 0; i < numVertices; i++)
+					{
+						visuals->m_vertices[i].xyzw[0] = vertices[i][0];
+						visuals->m_vertices[i].xyzw[1] = vertices[i][1];
+						visuals->m_vertices[i].xyzw[2] = vertices[i][2];
+					}
+				}
+				if (visuals->m_vertices.size() == numNormals)
+				{
+					for (int i = 0; i < numVertices; i++)
+					{
+						visuals->m_vertices[i].normal[0] = normals[i][0];
+						visuals->m_vertices[i].normal[1] = normals[i][1];
+						visuals->m_vertices[i].normal[2] = normals[i][2];
+					}
+				}
+				m_data->m_instancingRenderer->updateShape(graphicsIndex, &visuals->m_vertices[0].xyzw[0],visuals->m_vertices.size());
+			}
+		}
+	}
+}
+
+
 // If you are getting segfaults in this function it may be ecause you are
-// compliling the plugin with differently from pybullet, try complining the
+// compliling the plugin with differently from pybullet, try compiling the
 // plugin with distutils too.
 int EGLRendererVisualShapeConverter::convertVisualShapes(
 	int linkIndex, const char* pathPrefix, const btTransform& localInertiaFrame,
 	const UrdfLink* linkPtr, const UrdfModel* model,
 	int orgGraphicsUniqueId, int bodyUniqueId, struct  CommonFileIOInterface* fileIO)
 {
-	if (orgGraphicsUniqueId< 0)
-	{
-		orgGraphicsUniqueId  = m_data->m_graphicsUniqueIdGenerator++;
-	}
+	btAssert(orgGraphicsUniqueId >= 0);
 	btAssert(linkPtr);  // TODO: remove if (not doing it now, because diff will be 50+ lines)
 	if (linkPtr)
 	{
@@ -1060,6 +1203,46 @@ int EGLRendererVisualShapeConverter::convertVisualShapes(
 				else
 				{
 					convertURDFToVisualShape2(vis, pathPrefix, tr, vertices, indices, textures, visualShape, fileIO, m_data->m_flags);
+
+					if ((vis->m_geometry.m_type == URDF_GEOM_PLANE) || (vis->m_geometry.m_type == URDF_GEOM_HEIGHTFIELD))
+					{
+						int texWidth = 1024;
+						int texHeight = 1024;
+						if (m_data->m_checkeredTexels.size() == 0)
+						{
+
+							int red = 173;
+							int green = 199;
+							int blue = 255;
+							//create a textured surface
+
+							m_data->m_checkeredTexels.resize(texWidth * texHeight * 3);
+							for (int i = 0; i < texWidth * texHeight * 3; i++)
+								m_data->m_checkeredTexels[i] = 255;
+
+							for (int i = 0; i < texWidth; i++)
+							{
+								for (int j = 0; j < texHeight; j++)
+								{
+									int a = i < texWidth / 2 ? 1 : 0;
+									int b = j < texWidth / 2 ? 1 : 0;
+
+									if (a == b)
+									{
+										m_data->m_checkeredTexels[(i + j * texWidth) * 3 + 0] = red;
+										m_data->m_checkeredTexels[(i + j * texWidth) * 3 + 1] = green;
+										m_data->m_checkeredTexels[(i + j * texWidth) * 3 + 2] = blue;
+									}
+								}
+							}
+						}
+						MyTexture3 texData;
+						texData.m_width = texWidth;
+						texData.m_height = texHeight;
+						texData.textureData1 = &m_data->m_checkeredTexels[0];
+						texData.m_isCached = true;
+						textures.push_back(texData);
+					}
 				}
 			}
 			m_data->m_visualShapes.push_back(visualShape);
@@ -1101,19 +1284,24 @@ int EGLRendererVisualShapeConverter::convertVisualShapes(
 
 				// register mesh to m_instancingRenderer too.
 
-				if (shapeIndex < 0)
+				if (shapeIndex < 0 && vertices.size() > 0)
 				{
 					shapeIndex = m_data->m_instancingRenderer->registerShape(&vertices[0].xyzw[0], vertices.size(), &indices[0], indices.size(), B3_GL_TRIANGLES, textureIndex);
 					m_data->m_cachedVisualShapes.insert(tmp, shapeIndex);
 				}
 				double scaling[3] = { 1, 1, 1 };
 				int graphicsIndex = m_data->m_instancingRenderer->registerGraphicsInstance(shapeIndex, &visualShape.m_localVisualFrame[0], &visualShape.m_localVisualFrame[3], &visualShape.m_rgbaColor[0], scaling);
-
+				
 				int segmentationMask = bodyUniqueId + ((linkIndex + 1) << 24);
 				{
 					if (graphicsIndex >= 0)
 					{
 						visuals->m_graphicsInstanceIds.push_back(graphicsIndex);
+						visuals->m_vertices.resize(vertices.size());
+						for (int v = 0; v < vertices.size(); v++)
+						{
+							visuals->m_vertices[v] = vertices[v];
+						}
 
 						if (m_data->m_graphicsIndexToSegmentationMask.size() < (graphicsIndex + 1))
 						{
@@ -1196,21 +1384,52 @@ int EGLRendererVisualShapeConverter::getVisualShapesData(int bodyUniqueId, int s
 	return 0;
 }
 
-void EGLRendererVisualShapeConverter::changeRGBAColor(int bodyUniqueId, int linkIndex, int shapeIndex, const double rgbaColor[4])
+void EGLRendererVisualShapeConverter::changeInstanceFlags(int bodyUniqueId, int linkIndex, int shapeIndex, int flags)
 {
-	//int start = -1;
-	for (int i = 0; i < m_data->m_visualShapes.size(); i++)
+	for (int i = 0; i < m_data->m_swRenderInstances.size(); i++)
 	{
-		if (m_data->m_visualShapes[i].m_objectUniqueId == bodyUniqueId && m_data->m_visualShapes[i].m_linkIndex == linkIndex)
+		EGLRendererObjectArray** ptrptr = m_data->m_swRenderInstances.getAtIndex(i);
+		if (ptrptr && *ptrptr)
 		{
-			m_data->m_visualShapes[i].m_rgbaColor[0] = rgbaColor[0];
-			m_data->m_visualShapes[i].m_rgbaColor[1] = rgbaColor[1];
-			m_data->m_visualShapes[i].m_rgbaColor[2] = rgbaColor[2];
-			m_data->m_visualShapes[i].m_rgbaColor[3] = rgbaColor[3];
-			m_data->m_instancingRenderer->writeSingleInstanceColorToCPU(rgbaColor,i);
+			EGLRendererObjectArray* visuals = *ptrptr;
+			for (int v = 0; v < visuals->m_graphicsInstanceIds.size(); v++)
+			{
+				int graphicsInstance = visuals->m_graphicsInstanceIds[v];
+				if (graphicsInstance >= 0)
+				{
+					m_data->m_instancingRenderer->writeSingleInstanceFlagsToCPU(flags, graphicsInstance);
+				}
+			}
 		}
 	}
+}
 
+void EGLRendererVisualShapeConverter::changeShapeTexture(int bodyUniqueId, int linkIndex, int shapeIndex, int textureUniqueId)
+{
+	btAssert(textureUniqueId < m_data->m_textures.size());
+	if (textureUniqueId >= 0 && textureUniqueId < m_data->m_textures.size())
+	{
+		for (int i = 0; i < m_data->m_swRenderInstances.size(); i++)
+		{
+			EGLRendererObjectArray** ptrptr = m_data->m_swRenderInstances.getAtIndex(i);
+			if (ptrptr && *ptrptr)
+			{
+				EGLRendererObjectArray* visuals = *ptrptr;
+				if ((bodyUniqueId == visuals->m_objectUniqueId) && (linkIndex == visuals->m_linkIndex))
+				{
+					for (int i = 0; i < visuals->m_graphicsInstanceIds.size(); i++)
+					{
+						m_data->m_instancingRenderer->replaceTexture(visuals->m_graphicsInstanceIds[i], textureUniqueId);
+					}
+					
+				}
+			}
+		}
+	}
+}
+
+void EGLRendererVisualShapeConverter::changeRGBAColor(int bodyUniqueId, int linkIndex, int shapeIndex, const double rgbaColor[4])
+{
 	for (int i = 0; i < m_data->m_swRenderInstances.size(); i++)
 	{
 		EGLRendererObjectArray** ptrptr = m_data->m_swRenderInstances.getAtIndex(i);
@@ -1220,6 +1439,10 @@ void EGLRendererVisualShapeConverter::changeRGBAColor(int bodyUniqueId, int link
 			EGLRendererObjectArray* visuals = *ptrptr;
 			if ((bodyUniqueId == visuals->m_objectUniqueId) && (linkIndex == visuals->m_linkIndex))
 			{
+				for (int i = 0; i < visuals->m_graphicsInstanceIds.size(); i++)
+				{
+					m_data->m_instancingRenderer->writeSingleInstanceColorToCPU(rgbaColor, visuals->m_graphicsInstanceIds[i]);
+				}
 				
 			}
 		}
@@ -1241,6 +1464,7 @@ void EGLRendererVisualShapeConverter::resetCamera(float camDist, float yaw, floa
 	m_data->m_camera.setCameraTargetPosition(camPosX, camPosY, camPosZ);
 	m_data->m_camera.setAspectRatio((float)m_data->m_swWidth / (float)m_data->m_swHeight);
 	m_data->m_camera.update();
+	
 }
 
 void EGLRendererVisualShapeConverter::clearBuffers(TGAColor& clearColor)
@@ -1350,9 +1574,6 @@ void EGLRendererVisualShapeConverter::copyCameraImageDataGL(
 			m_data->m_instancingRenderer->updateCamera(m_data->m_upAxis);
 
 			m_data->m_instancingRenderer->renderScene();
-			m_data->m_instancingRenderer->drawLine(b3MakeVector3(0, 0, 0), b3MakeVector3(1, 0, 0), b3MakeVector3(1, 0, 0), 3);
-			m_data->m_instancingRenderer->drawLine(b3MakeVector3(0, 0, 0), b3MakeVector3(0, 1, 0), b3MakeVector3(0, 1, 0), 3);
-			m_data->m_instancingRenderer->drawLine(b3MakeVector3(0, 0, 0), b3MakeVector3(0, 0, 1), b3MakeVector3(0, 0, 1), 3);
 
 			int numBytesPerPixel = 4;  //RGBA
 
@@ -1580,12 +1801,10 @@ void EGLRendererVisualShapeConverter::resetAll()
 		if (ptrptr && *ptrptr)
 		{
 			EGLRendererObjectArray* ptr = *ptrptr;
-			if (ptr)
-			{
-				
-			}
+			
 			delete ptr;
 		}
+
 	}
 
 	for (int i = 0; i < m_data->m_textures.size(); i++)
@@ -1603,22 +1822,28 @@ void EGLRendererVisualShapeConverter::resetAll()
 	m_data->m_cachedVisualShapes.clear();
 }
 
-void EGLRendererVisualShapeConverter::changeShapeTexture(int objectUniqueId, int jointIndex, int shapeIndex, int textureUniqueId)
-{
-	btAssert(textureUniqueId < m_data->m_textures.size());
-	if (textureUniqueId >= 0 && textureUniqueId < m_data->m_textures.size())
-	{
-		
-	}
-}
+
 
 int EGLRendererVisualShapeConverter::registerTexture(unsigned char* texels, int width, int height)
+{
+	MyTexture3 texData;
+	texData.m_width = width;
+	texData.m_height = height;
+	texData.textureData1 = texels;
+	texData.m_isCached = true;
+	texData.m_innerTexUid = m_data->m_instancingRenderer->registerTexture(texels, width, height);
+	m_data->m_textures.push_back(texData);
+	return m_data->m_textures.size() - 1;
+}
+
+int EGLRendererVisualShapeConverter::registerTextureInternal(unsigned char* texels, int width, int height)
 {
 	MyTexture3 texData;
 	texData.m_width = width;
 	texData.m_height = height;
 	texData.textureData1 = texels;
 	texData.m_isCached = false;
+	texData.m_innerTexUid = m_data->m_instancingRenderer->registerTexture(texels, width, height);
 	m_data->m_textures.push_back(texData);
 	return m_data->m_textures.size() - 1;
 }
@@ -1660,7 +1885,7 @@ int EGLRendererVisualShapeConverter::loadTextureFile(const char* filename, struc
 
 	if (image && (width >= 0) && (height >= 0))
 	{
-		return registerTexture(image, width, height);
+		return registerTextureInternal(image, width, height);
 	}
 	return -1;
 }
