@@ -1,5 +1,8 @@
 import pybullet as p
-p.connect(p.GUI)  #or p.SHARED_MEMORY or p.DIRECT
+import pybullet_data
+
+p.connect(p.GUI)
+p.setAdditionalSearchPath(pybullet_data.getDataPath())
 
 p.loadURDF("plane.urdf")
 p.setGravity(0, 0, -10)
